==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/User.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface User extends BusinessEntity {     String EXT_USER = "User";
     String FIELD_USER_NAME = "name";
     String FQ_FIELD_USER_NAME = EXT_USER + ".name";
     String FIELD_USER_SERVICE = "service";
     String FQ_FIELD_USER_SERVICE = EXT_USER + ".service";
     String FIELD_USER_EMAIL = "email";
     String FQ_FIELD_USER_EMAIL = EXT_USER + ".email";
     String FIELD_USER_CREATIONDATE = "creationDate";
     String FQ_FIELD_USER_CREATIONDATE = EXT_USER + ".creationDate";
     String FIELD_USER_VALIDEMAIL = "validEmail";
     String FQ_FIELD_USER_VALIDEMAIL = EXT_USER + ".validEmail";
     String FIELD_USER_ADDRESS = "address";
     String FQ_FIELD_USER_ADDRESS = EXT_USER + ".address";
     String FIELD_USER_PHONE = "phone";
     String FQ_FIELD_USER_PHONE = EXT_USER + ".phone";
     String FIELD_USER_BEGINSEARCHDATE = "beginSearchDate";
     String FQ_FIELD_USER_BEGINSEARCHDATE = EXT_USER + ".beginSearchDate";
     String FIELD_USER_ENABLE = "enable";
     String FQ_FIELD_USER_ENABLE = EXT_USER + ".enable";
     String FIELD_USER_CLIENT = "client";
     String FQ_FIELD_USER_CLIENT = EXT_USER + ".client";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getService :
     * @return String 
     */

     String getService();

    /**
     * setService :
     * @param service 
     */

     void setService(String service);

    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getValidEmail :
     * @return boolean 
     */

     boolean getValidEmail();

    /**
     * setValidEmail :
     * @param validEmail 
     */

     void setValidEmail(boolean validEmail);

    /**
     * getAddress :
     * @return String 
     */

     String getAddress();

    /**
     * setAddress :
     * @param address 
     */

     void setAddress(String address);

    /**
     * getPhone :
     * @return String 
     */

     String getPhone();

    /**
     * setPhone :
     * @param phone 
     */

     void setPhone(String phone);

    /**
     * getBeginSearchDate :
     * @return Date 
     */

     Date getBeginSearchDate();

    /**
     * setBeginSearchDate :
     * @param beginSearchDate 
     */

     void setBeginSearchDate(Date beginSearchDate);

    /**
     * getEnable :
     * @return boolean 
     */

     boolean getEnable();

    /**
     * setEnable :
     * @param enable 
     */

     void setEnable(boolean enable);

    /**
     * getClient :
     * @return String 
     */

     String getClient();

    /**
     * setClient :
     * @param client 
     */

     void setClient(String client);


} //User

==> vradi-entities-0.3.1-sources.jar: com/jurismarches/vradi/entities/User.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface User extends BusinessEntity {     String EXT_USER = "User";
     String FIELD_USER_NAME = "name";
     String FQ_FIELD_USER_NAME = EXT_USER + ".name";
     String FIELD_USER_SERVICE = "service";
     String FQ_FIELD_USER_SERVICE = EXT_USER + ".service";
     String FIELD_USER_EMAIL = "email";
     String FQ_FIELD_USER_EMAIL = EXT_USER + ".email";
     String FIELD_USER_CREATIONDATE = "creationDate";
     String FQ_FIELD_USER_CREATIONDATE = EXT_USER + ".creationDate";
     String FIELD_USER_VALIDEMAIL = "validEmail";
     String FQ_FIELD_USER_VALIDEMAIL = EXT_USER + ".validEmail";
     String FIELD_USER_ADDRESS = "address";
     String FQ_FIELD_USER_ADDRESS = EXT_USER + ".address";
     String FIELD_USER_PHONE = "phone";
     String FQ_FIELD_USER_PHONE = EXT_USER + ".phone";
     String FIELD_USER_BEGINSEARCHDATE = "beginSearchDate";
     String FQ_FIELD_USER_BEGINSEARCHDATE = EXT_USER + ".beginSearchDate";
     String FIELD_USER_ENABLE = "enable";
     String FQ_FIELD_USER_ENABLE = EXT_USER + ".enable";
     String FIELD_USER_CLIENT = "client";
     String FQ_FIELD_USER_CLIENT = EXT_USER + ".client";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getService :
     * @return String 
     */

     String getService();

    /**
     * setService :
     * @param service 
     */

     void setService(String service);

    /**
     * getEmail :
     * @return String 
     */

     String getEmail();

    /**
     * setEmail :
     * @param email 
     */

     void setEmail(String email);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getValidEmail :
     * @return boolean 
     */

     boolean getValidEmail();

    /**
     * setValidEmail :
     * @param validEmail 
     */

     void setValidEmail(boolean validEmail);

    /**
     * getAddress :
     * @return String 
     */

     String getAddress();

    /**
     * setAddress :
     * @param address 
     */

     void setAddress(String address);

    /**
     * getPhone :
     * @return String 
     */

     String getPhone();

    /**
     * setPhone :
     * @param phone 
     */

     void setPhone(String phone);

    /**
     * getBeginSearchDate :
     * @return Date 
     */

     Date getBeginSearchDate();

    /**
     * setBeginSearchDate :
     * @param beginSearchDate 
     */

     void setBeginSearchDate(Date beginSearchDate);

    /**
     * getEnable :
     * @return boolean 
     */

     boolean getEnable();

    /**
     * setEnable :
     * @param enable 
     */

     void setEnable(boolean enable);

    /**
     * getClient :
     * @return String 
     */

     String getClient();

    /**
     * setClient :
     * @param client 
     */

     void setClient(String client);


} //User
